@@ -5,6 +5,7 @@
 */
 
 #include "libzipplugin.h"
+#include "../config.h"
 #include "ark_debug.h"
 #include "queries.h"
 
@@ -36,6 +37,11 @@ void LibzipPlugin::progressCallback(zip_t *, double progress, void *that)
     static_cast<LibzipPlugin *>(that)->emitProgress(progress);
 }
 
+int LibzipPlugin::cancelCallback(zip_t *, void * /* unused that*/)
+{
+    return QThread::currentThread()->isInterruptionRequested();
+}
+
 LibzipPlugin::LibzipPlugin(QObject *parent, const QVariantList & args)
     : ReadWriteArchiveInterface(parent, args)
     , m_overwriteAll(false)
@@ -153,12 +159,14 @@ bool LibzipPlugin::addFiles(const QVector<Archive::Entry*> &files, const Archive
         }
         i++;
     }
-    qCDebug(ARK) << "Added" << i << "entries";
+    qCDebug(ARK) << "Writing " << i << "entries to disk...";
 
-    // Register the callback function to get progress feedback.
+    // Register the callback function to get progress feedback and cancelation.
     zip_register_progress_callback_with_state(archive.get(), 0.001, progressCallback, nullptr, this);
+#ifdef LIBZIP_CANCELATION
+    zip_register_cancel_callback_with_state(archive.get(), cancelCallback, nullptr, this);
+#endif
 
-    qCDebug(ARK) << "Writing entries to disk...";
     // Write and close archive manually.
     zip_close(archive.get());
     // Release unique pointer as it set to NULL via zip_close.
@@ -169,6 +177,10 @@ bool LibzipPlugin::addFiles(const QVector<Archive::Entry*> &files, const Archive
         return false;
     }
 
+    if (QThread::currentThread()->isInterruptionRequested()) {
+        return false;
+    }
+
     // We list the entire archive after adding files to ensure entry
     // properties are up-to-date.
     m_listAfterAdd = true;
@@ -778,8 +790,9 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
         file.close();
     }
 
-    // Set mtime for entry.
+    // Set mtime for entry (also access time otherwise it's "uninitilized")
     utimbuf times;
+    times.actime = statBuffer.mtime;
     times.modtime = statBuffer.mtime;
     if (utime(destination.toUtf8().constData(), &times) != 0) {
         qCWarning(ARK) << "Failed to restore mtime:" << destination;
@@ -787,6 +800,7 @@ bool LibzipPlugin::extractEntry(zip_t *archive, const QString &entry, const QStr
 
     if (restoreParentMtime) {
         // Restore mtime for parent dir.
+        times.actime = parent_mtime;
         times.modtime = parent_mtime;
         if (utime(parentDir.toUtf8().constData(), &times) != 0) {
             qCWarning(ARK) << "Failed to restore mtime for parent dir of:" << destination;
@@ -920,8 +934,11 @@ bool LibzipPlugin::copyFiles(const QVector<Archive::Entry*> &files, Archive::Ent
         }
     }
 
-    // Register the callback function to get progress feedback.
+    // Register the callback function to get progress feedback and cancelation.
     zip_register_progress_callback_with_state(archive.get(), 0.001, progressCallback, nullptr, this);
+#ifdef LIBZIP_CANCELATION
+    zip_register_cancel_callback_with_state(archive.get(), cancelCallback, nullptr, this);
+#endif
 
     // Write and close archive manually before using list() function.
     zip_close(archive.get());
@@ -933,6 +950,10 @@ bool LibzipPlugin::copyFiles(const QVector<Archive::Entry*> &files, Archive::Ent
         return false;
     }
 
+    if (QThread::currentThread()->isInterruptionRequested()) {
+        return false;
+    }
+
     // List the archive to update the model.
     m_listAfterAdd = true;
     list();
